NAME
Graphics::Toolkit::Color::Manual - GTC documentation hub
INTRODUCTION
Welcome to the documentation of the Perl module Graphics::Toolkit::Color. It is an all-in-one solution to compute color sets, single colors, handle color names and to convert and reformat color definitions. It is mostly aimed toward the needs of a graphics programmer and designer but also contains color science and math. This page gives you an overview where to find what information about this library. If you do not find the needed information, please open a request on github.
INDEX
The manual encompasses the following pages:
Overviews
Overview - of the public API, short description of methods
CheatSheet - all methods, args and spaces on one page
Cookbook - code examples to solve real life problems
Philosophy - explaining the design and the mindset behind it
Reference
Constructor - ways to create a color object
Getter - methods that return information, but not a color object
Calculation - methods that calculate one related color
Set - methods that calculate sets of colors
Argument - explaining all arguments that several methods share
Topics
GUIDE
AUTHOR
Herbert Breunung, <lichtkind@cpan.org>
COPYRIGHT
Copyright 2026 Herbert Breunung.